# pydrinker

![build on github actions](https://github.com/pydrinker/pydrinker/actions/workflows/test.yml/badge.svg?branch=main)

This is a abstraction layer between [pydrinker-loafer](https://github.com/pydrinker/pydrinker-loafer) and all pydrinker libs, this project makes possible change thinks of original [olist-loafer](https://github.com/olist/olist-loafer) project, the future of this project is switch all core structure to here and remove pydrinker-loafer;

To understand more about pydrinker see [org page](https://github.com/pydrinker).
